==> elgg-1.10.1.zip: elgg-1.10.1/mod/bookmarks/languages/ko.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'bookmarks' => "책갈피",
	'bookmarks:add' => "책갈피 추가",
	'bookmarks:edit' => "책갈피 수정",
	'bookmarks:owner' => "%s의 책갈피",
	'bookmarks:friends' => "친구의 책갈피",
	'bookmarks:everyone' => "모든 책갈피",
	'bookmarks:this' => "이 문서를 책갈피에 넣습니다.",
	'bookmarks:this:group' => "%s 의 책갈피",
	'bookmarks:bookmarklet' => "책갈피 도구 얻기",
	'bookmarks:bookmarklet:group' => "모둠책갈피도구 얻기",
	'bookmarks:inbox' => "받은 책갈피 ",
	'bookmarks:with' => "공유하기",
	'bookmarks:new' => "새 책갈피",
	'bookmarks:address' => "책갈피 주소",
	'bookmarks:none' => '책갈피 없슴',

	'bookmarks:notify:summary' => '%s 라는 새 책갈피',
	'bookmarks:notify:subject' => '새 책갈피: %s',
	'bookmarks:notify:body' =>
'%s 가 새 책갈피 %s 를 추가하였습니다.

위치: %s

%s

책갈피를 보고 댓글을 남깁니다:
%s
',

	'bookmarks:delete:confirm' => "정말 이 내용을 삭제하겠습니까?",

	'bookmarks:numbertodisplay' => '표시할 책갈피의 수',

	'bookmarks:shared' => "책갈피에 추가됨",
	'bookmarks:visit' => "내용 보기",
	'bookmarks:recent' => "최근 책갈피",

	'river:create:object:bookmarks' => '%s 책갈피에 추가함 %s',
	'river:comment:object:bookmarks' => '%s가 책갈피 %s 에 댓글을 남겼습니다.',
	'bookmarks:river:annotate' => '이 책갈피의 댓글',
	'bookmarks:river:item' => '항목',

	'item:object:bookmarks' => '책갈피',

	'bookmarks:group' => '모둠 책갈피',
	'bookmarks:enablebookmarks' => '모둠 책갈피를 허용합니다',
	'bookmarks:nogroup' => '이 모둠은 아직 책갈피를 가지고 있지 않습니다.',
	
	/**
	 * Widget and bookmarklet
	 */
	'bookmarks:widget:description' => "최신의 책갈피를 표시합니다.",

	'bookmarks:bookmarklet:description' =>
			"책갈피도구는 웹브라우져의 즐겨찾기막대에 추가할 수 있는 특별한 형태의 단추입니다. 이것은 웹서핑 중 발견한 어떠한 내용도 당신의 책갈피에 저장할 수 있도록해주고, 또한 친구와 공유할 수도 있습니다. 이것을 설정하려면, 아래의 단추를 웹브라우져의 즐겨찾기막대에 끌어서 넣으세요.",

	'bookmarks:bookmarklet:descriptionie' =>
			"만약 인터넷익스플로러를 사용중이라면, 책갈피도구를 우클릭하고 \"즐겨찾기에 추가하기\"를 선택하고,  즐겨찾기막대를 선택하세요.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"이제 언제나 웹브라우져의 단추를 누름으로써 방문한 어떤 페이지라도 책갈피에 추가할 수 있습니다.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "항목이 성공적으로 책갈피에 추가되었습니다.",
	'bookmarks:delete:success' => "책갈피가 삭제되었습니다.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "책갈피를 저장할 수 없습니다. 제목과 주소를 입력했는지 확인하고 다시 시도해보세요.",
	'bookmarks:save:invalid' => "책갈피의 주소가 잘못되어 저장할 수 없습니다.",
	'bookmarks:delete:failed' => "책갈피를 삭제할 수 없습니다. 다시 시도해 보세요.",
	'bookmarks:unknown_bookmark' => '해당하는 책갈피를 찾을 수 없습니다.',
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/bookmarks/languages/ko.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'item:object:bookmarks' => '책갈피',
	'collection:object:bookmarks' => '책갈피',
	'collection:object:bookmarks:group' => '모둠 책갈피',
	'collection:object:bookmarks:all' => "사이트 전체 책갈피",
	'collection:object:bookmarks:owner' => "%s의 책갈피",
	'collection:object:bookmarks:friends' => "친구들의 책갈피",
	'add:object:bookmarks' => "책갈피 추가",
	'edit:object:bookmarks' => "책갈피 수정",

	'bookmarks:this' => "이 문서를 책갈피에 넣습니다.",
	'bookmarks:this:group' => "%s 의 책갈피",
	'bookmarks:bookmarklet' => "책갈피도구 얻기",
	'bookmarks:bookmarklet:group' => "모둠 책갈피도구 얻기",
	'bookmarks:address' => "책갈피 주소",
	'bookmarks:none' => '책갈피 없슴',

	'bookmarks:notify:summary' => '%s 라는 새 책갈피',
	'bookmarks:notify:subject' => '새 책갈피: %s',
	'bookmarks:notify:body' =>
'%s 가 새 책갈피 %s 를 추가하였습니다.

위치: %s

%s

책갈피를 보고 댓글을 남깁니다:
%s
',

	'bookmarks:numbertodisplay' => '표시할 책갈피의 수',

	'river:object:bookmarks:create' => '%s님이 %s를 책갈피에 추가하였습니다',
	'river:object:bookmarks:comment' => '%s님이 책갈피에 댓글 %s을 남겼습니다',

	'groups:tool:bookmarks' => '모둠 책갈피를 허용합니다',
	
	/**
	 * Widget and bookmarklet
	 */
	'widgets:bookmarks:name' => '책갈피',
	'widgets:bookmarks:description' => "최신의 책갈피를 표시합니다.",

	'bookmarks:bookmarklet:description' =>
			"책갈피도구는 웹브라우져의 즐겨찾기막대에 추가할 수 있는 특별한 형태의 단추입니다. 이것은 웹서핑 중 발견한 어떠한 내용도 당신의 책갈피에 저장할 수 있도록해주고, 또한 친구와 공유할 수도 있습니다. 이것을 설정하려면, 아래의 단추를 웹브라우져의 즐겨찾기막대에 끌어서 넣으세요.",

	'bookmarks:bookmarklet:descriptionie' =>
			"만약 인터넷익스플로러를 사용중이라면, 책갈피도구를 우클릭하고 \"즐겨찾기에 추가하기\"를 선택하고,  즐겨찾기막대를 선택하세요.",

	'bookmarks:bookmarklet:description:conclusion' =>
			"이제 언제나 웹브라우져의 단추를 누름으로써 방문한 어떤 페이지라도 책갈피에 추가할 수 있습니다.",

	/**
	 * Status messages
	 */

	'bookmarks:save:success' => "항목이 성공적으로 책갈피에 추가되었습니다.",
	'entity:delete:object:bookmarks:success' => "책갈피가 삭제되었습니다.",

	/**
	 * Error messages
	 */

	'bookmarks:save:failed' => "책갈피를 저장할 수 없습니다. 제목과 주소를 입력했는지 확인하고 다시 시도해보세요.",
	'bookmarks:unknown_bookmark' => '해당하는 책갈피를 찾을 수 없습니다.',
);
